q1ss.binalg.base
================

.. automodule:: q1ss.binalg.base

Shape
-----

.. autodata:: q1ss.binalg.base.Shape

bintensor
---------

.. autoclass:: q1ss.binalg.base.bintensor
    :show-inheritance:
    :members:
    :special-members: __neg__, __pos__, __add__, __mul__, __sub__, __iadd__, __imul__, __isub__, __new__
